<?php
namespace SBTheke\Cefooter\Hook;

use TYPO3\CMS\Core\Utility\GeneralUtility;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2018 Sven Burkert <bedienung@sbtheke.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

class Cms implements \TYPO3\CMS\Backend\View\PageLayoutViewDrawFooterHookInterface {

    /**
     * Preprocesses the preview footer rendering of a content element.
     *
     * @param \TYPO3\CMS\Backend\View\PageLayoutView $parentObject Calling parent object
     * @param array $info Processed values
     * @param array $row Record row of tt_content
     */
    public function preProcess(\TYPO3\CMS\Backend\View\PageLayoutView &$parentObject, &$info, array &$row) {
        // Handle $info, if it is a string (EXT:gridelements bug), @see https://forge.typo3.org/issues/84673
        // @TODO: remove, when bug is fixed
        if(!is_array($info)) {
            $info = GeneralUtility::trimExplode(',', $info);
        }
        // Remove empty footer entry, @see https://forge.typo3.org/issues/84602
        // @TODO: remove, when bug is fixed
        foreach($info as $k => $v) {
            if(!$v) {
                unset($info[$k]);
            }
        }

        $pageTSconfig = \TYPO3\CMS\Backend\Utility\BackendUtility::getPagesTSconfig($row['pid']);

        $showFields = $GLOBALS['BE_USER']->getTSConfig(
            'mod.web_layout.tt_content_footer.show',
            $pageTSconfig
        );
        if($showFields['value']) {
            $showFields = GeneralUtility::trimExplode(',', $showFields['value']);
            foreach($showFields as $k => $field) {
                $showFieldCond = $GLOBALS['BE_USER']->getTSConfig(
                    sprintf('mod.web_layout.tt_content_footer.displayCond.%s', $field),
                    $pageTSconfig
                );
                if($showFieldCond['properties']) {
                    foreach($showFieldCond['properties'] as $cond) {
                        $condField = $field;
                        if($cond['field']) {
                            $condField = $cond['field'];
                        }
                        if($cond['valuesNot']) {
                            if(in_array($row[$condField],
                                GeneralUtility::trimExplode(',', $cond['valuesNot']))) {
                                unset($showFields[$k]);
                            }
                        }
                        if($cond['values']) {
                            if(!in_array($row[$condField],
                                GeneralUtility::trimExplode(',', $cond['values']))) {
                                unset($showFields[$k]);
                            }
                        }
                    }
                }
            }
            if($showFields) {
                $parentObject->getProcessedValue('tt_content', implode(',', $showFields), $row, $info);
            }
        }
    }

}